@@ -1261,7 +1261,7 @@ static hostlist_t hostlist_new(void)
 	if (!new)
 		goto fail1;
 
-	assert(new->magic = HOSTLIST_MAGIC);
+	assert((new->magic = HOSTLIST_MAGIC));
 	slurm_mutex_init(&new->mutex);
 
 	new->hr = (hostrange_t *) malloc(HOSTLIST_CHUNK * sizeof(hostrange_t));
@@ -1984,7 +1984,7 @@ void hostlist_destroy(hostlist_t hl)
 	for (i = 0; i < hl->nranges; i++)
 		hostrange_destroy(hl->hr[i]);
 	free(hl->hr);
-	assert(hl->magic = 0x1);
+	assert((hl->magic = 0x1));
 	UNLOCK_HOSTLIST(hl);
 	slurm_mutex_destroy(&hl->mutex);
 	free(hl);
@@ -3311,7 +3311,7 @@ static hostlist_iterator_t hostlist_iterator_new(void)
 	i->idx = 0;
 	i->depth = -1;
 	i->next = i;
-	assert(i->magic = HOSTLIST_MAGIC);
+	assert((i->magic = HOSTLIST_MAGIC));
 	return i;
 }
 
@@ -3362,7 +3362,7 @@ void hostlist_iterator_destroy(hostlist_iterator_t i)
 		}
 	}
 	UNLOCK_HOSTLIST(i->hl);
-	assert(i->magic = 0x1);
+	assert((i->magic = 0x1));
 	free(i);
 }
 
