@@ -683,14 +683,22 @@ static int _as_mysql_acct_check_tables(mysql_conn_t *mysql_conn)
 		/* "@mtrm := REPLACE(CONCAT(@mtrm, max_tres_run_mins), " */
 		/* "\\\',,\\\', \\\',\\\'), '); " */
 		"set @s = concat(@s, "
-		"'@mtpj := REPLACE(CONCAT(@mtpj, max_tres_pj), "
-		"\\\',,\\\', \\\',\\\'), "
-		"@mtpn := REPLACE(CONCAT(@mtpn, max_tres_pn), "
-		"\\\',,\\\', \\\',\\\'), "
-		"@mtmpj := REPLACE(CONCAT(@mtmpj, max_tres_mins_pj), "
-		"\\\',,\\\', \\\',\\\'), "
-		"@mtrm := REPLACE(CONCAT(@mtrm, max_tres_run_mins), "
-		"\\\',,\\\', \\\',\\\'), "
+		"'@mtpj := REPLACE(CONCAT(@mtpj, "
+		"if (@mtpj != \\\'\\\' && max_tres_pj != \\\'\\\', "
+		"\\\',\\\', \\\'\\\'), "
+		"max_tres_pj), \\\',,\\\', \\\',\\\'), "
+		"@mtpn := REPLACE(CONCAT(@mtpn, "
+		"if (@mtpn != \\\'\\\' && max_tres_pn != \\\'\\\', "
+		"\\\',\\\', \\\'\\\'), "
+		"max_tres_pn), \\\',,\\\', \\\',\\\'), "
+		"@mtmpj := REPLACE(CONCAT(@mtmpj, "
+		"if (@mtmpj != \\\'\\\' && max_tres_mins_pj != \\\'\\\', "
+		"\\\',\\\', \\\'\\\'), "
+		"max_tres_mins_pj), \\\',,\\\', \\\',\\\'), "
+		"@mtrm := REPLACE(CONCAT(@mtrm, "
+		"if (@mtrm != \\\'\\\' && max_tres_run_mins != \\\'\\\', "
+		"\\\',\\\', \\\'\\\'), "
+		"max_tres_run_mins), \\\',,\\\', \\\',\\\'), "
 		"@my_acct_new := parent_acct from \"', "
 		"cluster, '_', my_table, '\" where "
 		"acct = \\\'', @my_acct, '\\\' && user=\\\'\\\''); "
