@@ -349,9 +349,9 @@ static void *_set_db_inx_thread(void *no_data)
 			} else if (resp.msg_type == PERSIST_RC) {
 				persist_rc_msg_t *msg = resp.data;
 				if (msg->rc == SLURM_SUCCESS) {
-					info("%s", msg->comment);
+					info("slurmdbd: %s", msg->comment);
 				} else
-					error("%s", msg->comment);
+					error("slurmdbd: %s", msg->comment);
 				slurm_persist_free_rc_msg(msg);
 				reset = 1;
 			} else if (resp.msg_type != DBD_GOT_MULT_JOB_START) {
@@ -827,11 +827,11 @@ extern List acct_storage_p_modify_users(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -870,11 +870,11 @@ extern List acct_storage_p_modify_accts(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -915,11 +915,11 @@ extern List acct_storage_p_modify_clusters(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -961,11 +961,11 @@ extern List acct_storage_p_modify_assocs(
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1007,11 +1007,11 @@ extern List acct_storage_p_modify_federations(
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1050,11 +1050,11 @@ extern List acct_storage_p_modify_job(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1093,11 +1093,11 @@ extern List acct_storage_p_modify_qos(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1136,11 +1136,11 @@ extern List acct_storage_p_modify_res(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1179,11 +1179,11 @@ extern List acct_storage_p_modify_wckeys(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1262,11 +1262,11 @@ extern List acct_storage_p_remove_users(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1308,11 +1308,11 @@ extern List acct_storage_p_remove_coord(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1350,11 +1350,11 @@ extern List acct_storage_p_remove_accts(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1394,11 +1394,11 @@ extern List acct_storage_p_remove_clusters(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1440,11 +1440,11 @@ extern List acct_storage_p_remove_assocs(
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1485,11 +1485,11 @@ extern List acct_storage_p_remove_federations(
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1531,11 +1531,11 @@ extern List acct_storage_p_remove_qos(
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1573,11 +1573,11 @@ extern List acct_storage_p_remove_res(
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1616,11 +1616,11 @@ extern List acct_storage_p_remove_wckeys(
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_LIST) {
@@ -1695,11 +1695,11 @@ extern List acct_storage_p_get_users(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_USERS) {
@@ -1736,11 +1736,11 @@ extern List acct_storage_p_get_accts(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_ACCOUNTS) {
@@ -1778,11 +1778,11 @@ extern List acct_storage_p_get_clusters(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_CLUSTERS) {
@@ -1820,11 +1820,11 @@ extern List acct_storage_p_get_federations(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_FEDERATIONS) {
@@ -1860,11 +1860,11 @@ extern List acct_storage_p_get_config(void *db_conn, char *config_name)
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_CONFIG) {
@@ -1901,11 +1901,11 @@ extern List acct_storage_p_get_tres(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_TRES) {
@@ -1942,11 +1942,11 @@ extern List acct_storage_p_get_assocs(
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_ASSOCS) {
@@ -1983,11 +1983,11 @@ extern List acct_storage_p_get_events(void *db_conn, uint32_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_EVENTS) {
@@ -2024,11 +2024,11 @@ extern List acct_storage_p_get_problems(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_PROBS) {
@@ -2065,11 +2065,11 @@ extern List acct_storage_p_get_qos(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_QOS) {
@@ -2113,11 +2113,11 @@ extern List acct_storage_p_get_res(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_RES) {
@@ -2161,11 +2161,11 @@ extern List acct_storage_p_get_wckeys(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_WCKEYS) {
@@ -2210,11 +2210,11 @@ extern List acct_storage_p_get_reservations(
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_RESVS) {
@@ -2258,11 +2258,11 @@ extern List acct_storage_p_get_txn(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			ret_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_TXN) {
@@ -2322,11 +2322,11 @@ extern int acct_storage_p_get_usage(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			(*my_list) = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_ASSOC_USAGE
@@ -2878,11 +2878,11 @@ extern List jobacct_storage_p_get_jobs_cond(void *db_conn, uid_t uid,
 	else if (resp.msg_type == PERSIST_RC) {
 		persist_rc_msg_t *msg = resp.data;
 		if (msg->rc == SLURM_SUCCESS) {
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 			my_job_list = list_create(NULL);
 		} else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else if (resp.msg_type != DBD_GOT_JOBS) {
@@ -2925,10 +2925,10 @@ extern int jobacct_storage_p_archive(void *db_conn,
 		rc = msg->rc;
 
 		if (msg->rc == SLURM_SUCCESS)
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 		else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else {
@@ -2960,10 +2960,10 @@ extern int jobacct_storage_p_archive_load(void *db_conn,
 		rc = msg->rc;
 
 		if (msg->rc == SLURM_SUCCESS)
-			info("%s", msg->comment);
+			info("slurmdbd: %s", msg->comment);
 		else {
 			slurm_seterrno(msg->rc);
-			error("%s", msg->comment);
+			error("slurmdbd: %s", msg->comment);
 		}
 		slurm_persist_free_rc_msg(msg);
 	} else {
