@@ -108,7 +108,7 @@ extern int node_config_load(List gres_conf_list)
 	while ((gres_slurmd_conf = list_next(iter))) {
 		if (xstrcmp(gres_slurmd_conf->name, gres_name))
 			continue;
-		if (gres_slurmd_conf->file)
+		if (gres_slurmd_conf->has_file == 1)
 			nb_mic++;
 	}
 	list_iterator_destroy(iter);
@@ -126,8 +126,9 @@ extern int node_config_load(List gres_conf_list)
 
 	iter = list_iterator_create(gres_conf_list);
 	while ((gres_slurmd_conf = list_next(iter))) {
-		if ((xstrcmp(gres_slurmd_conf->name, gres_name) == 0) &&
-		    gres_slurmd_conf->file) {
+		if ((gres_slurmd_conf->has_file == 1) &&
+		    gres_slurmd_conf->file &&
+		    !xstrcmp(gres_slurmd_conf->name, gres_name)) {
 			/* Populate mic_devices array with number
 			 * at end of the file name */
 			for (i = 0; gres_slurmd_conf->file[i]; i++) {
