@@ -122,7 +122,7 @@ extern int node_config_load(List gres_conf_list)
 	while ((gres_slurmd_conf = list_next(iter))) {
 		if (xstrcmp(gres_slurmd_conf->name, gres_name))
 			continue;
-		if (gres_slurmd_conf->file)
+		if (gres_slurmd_conf->has_file == 1)
 			nb_nic++;
 	}
 	list_iterator_destroy(iter);
@@ -138,8 +138,9 @@ extern int node_config_load(List gres_conf_list)
 
 	iter = list_iterator_create(gres_conf_list);
 	while ((gres_slurmd_conf = list_next(iter))) {
-		if ((xstrcmp(gres_slurmd_conf->name, gres_name) == 0) &&
-		    gres_slurmd_conf->file) {
+		if ((gres_slurmd_conf->has_file == 1) &&
+		    gres_slurmd_conf->file &&
+		    !xstrcmp(gres_slurmd_conf->name, gres_name)) {
 			/* Populate nic_devices array with number
 			 * at end of the file name */
 			char *bracket, *fname, *tmp_name;
