@@ -1403,6 +1403,19 @@ fail1:
 	return(rc);
 }
 
+static int _pre_task_child_privileged(
+	stepd_step_rec_t *job, int taskid, struct priv_state *sp)
+{
+	if (_reclaim_privileges(sp) < 0)
+		return SLURM_ERROR;
+
+	if (spank_task_privileged(job, taskid) < 0)
+		return error("spank_task_init_privileged failed");
+
+	/* sp->gid_list should already be initialized */
+	return (_drop_privileges(job, true, sp, false));
+}
+
 struct exec_wait_info {
 	int id;
 	pid_t pid;
@@ -1712,6 +1725,17 @@ _fork_all_tasks(stepd_step_rec_t *job, bool *io_initialized)
 			if (conf->propagate_prio)
 				_set_prio_process(job);
 
+			/*
+			 * Reclaim privileges for the child and call any plugin
+			 * hooks that may require elevated privs
+			 * sprivs.gid_list is already set from the
+			 * _drop_privileges call above, no not reinitialize.
+			 * NOTE: Only put things in here that are self contained
+			 * and belong in the child.
+			 */
+			if (_pre_task_child_privileged(job, i, &sprivs) < 0)
+				exit(1);
+
  			if (_become_user(job, &sprivs) < 0) {
  				error("_become_user failed: %m");
 				/* child process, should not return */
@@ -1797,12 +1821,6 @@ _fork_all_tasks(stepd_step_rec_t *job, bool *io_initialized)
 			      i, job->task[i]->pid, job->pgid);
 		}
 
-		if (spank_task_privileged(job, i) < 0) {
-			error("spank_task_privileged: %m");
-			rc = SLURM_ERROR;
-			goto fail2;
-		}
-
 		if (task_g_pre_launch_priv(job, job->task[i]->pid) < 0) {
 			error("task_g_pre_launch_priv: %m");
 			rc = SLURM_ERROR;
@@ -1837,7 +1855,8 @@ _fork_all_tasks(stepd_step_rec_t *job, bool *io_initialized)
 //	jobacct_gather_set_proctrack_container_id(job->cont_id);
 	if (container_g_add_cont(job->jobid, job->cont_id) != SLURM_SUCCESS)
 		error("container_g_add_cont(%u): %m", job->jobid);
-	if (!job->batch && core_spec_g_set(job->cont_id, job->job_core_spec))
+	if (!job->batch && core_spec_g_set(job->cont_id, job->job_core_spec) &&
+	    (job->stepid == 0))
 		error("core_spec_g_set: %m");
 
 	/*
