@@ -1045,6 +1045,9 @@ static void _admin_front_end(GtkTreeModel *model, GtkTreeIter *iter, char *type,
 		GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		NULL);
 
+	gtk_window_set_type_hint(GTK_WINDOW(popup),
+				 GDK_WINDOW_TYPE_HINT_NORMAL);
+
 	gtk_window_set_transient_for(GTK_WINDOW(popup), NULL);
 
 	label = gtk_dialog_add_button(GTK_DIALOG(popup),
